==> aws-java-sdk-inspector-1.10.75.1-sources.jar: com/amazonaws/services/inspector/model/transform/ListAssessmentTemplatesRequestMarshaller.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.inspector.model.transform;

import java.io.ByteArrayInputStream;
import java.util.Collections;
import java.util.Map;
import java.util.List;
import java.util.regex.Pattern;

import com.amazonaws.AmazonClientException;
import com.amazonaws.Request;
import com.amazonaws.DefaultRequest;
import com.amazonaws.http.HttpMethodName;
import com.amazonaws.services.inspector.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.BinaryUtils;
import com.amazonaws.util.StringUtils;
import com.amazonaws.util.IdempotentUtils;
import com.amazonaws.util.StringInputStream;
import com.amazonaws.util.json.*;

/**
 * ListAssessmentTemplatesRequest Marshaller
 */
public class ListAssessmentTemplatesRequestMarshaller
        implements
        Marshaller<Request<ListAssessmentTemplatesRequest>, ListAssessmentTemplatesRequest> {

    public Request<ListAssessmentTemplatesRequest> marshall(
            ListAssessmentTemplatesRequest listAssessmentTemplatesRequest) {

        if (listAssessmentTemplatesRequest == null) {
            throw new AmazonClientException(
                    "Invalid argument passed to marshall(...)");
        }

        Request<ListAssessmentTemplatesRequest> request = new DefaultRequest<ListAssessmentTemplatesRequest>(
                listAssessmentTemplatesRequest, "AmazonInspector");
        request.addHeader("X-Amz-Target",
                "InspectorService.ListAssessmentTemplates");

        request.setHttpMethod(HttpMethodName.POST);

        request.setResourcePath("");

        try {
            final StructuredJsonGenerator jsonGenerator = SdkJsonProtocolFactory
                    .createWriter(false, "1.1");

            jsonGenerator.writeStartObject();

            java.util.List<String> assessmentTargetArnsList = listAssessmentTemplatesRequest
                    .getAssessmentTargetArns();
            if (assessmentTargetArnsList != null) {
                jsonGenerator.writeFieldName("assessmentTargetArns");
                jsonGenerator.writeStartArray();
                for (String assessmentTargetArnsListValue : assessmentTargetArnsList) {
                    if (assessmentTargetArnsListValue != null) {
                        jsonGenerator.writeValue(assessmentTargetArnsListValue);
                    }
                }
                jsonGenerator.writeEndArray();
            }
            if (listAssessmentTemplatesRequest.getFilter() != null) {
                jsonGenerator.writeFieldName("filter");
                AssessmentTemplateFilterJsonMarshaller.getInstance().marshall(
                        listAssessmentTemplatesRequest.getFilter(),
                        jsonGenerator);
            }
            if (listAssessmentTemplatesRequest.getNextToken() != null) {
                jsonGenerator.writeFieldName("nextToken").writeValue(
                        listAssessmentTemplatesRequest.getNextToken());
            }
            if (listAssessmentTemplatesRequest.getMaxResults() != null) {
                jsonGenerator.writeFieldName("maxResults").writeValue(
                        listAssessmentTemplatesRequest.getMaxResults());
            }

            jsonGenerator.writeEndObject();

            byte[] content = jsonGenerator.getBytes();
            request.setContent(new ByteArrayInputStream(content));
            request.addHeader("Content-Length",
                    Integer.toString(content.length));
            request.addHeader("Content-Type", jsonGenerator.getContentType());
        } catch (Throwable t) {
            throw new AmazonClientException(
                    "Unable to marshall request to JSON: " + t.getMessage(), t);
        }

        return request;
    }

}

==> aws-java-sdk-inspector-1.11.15-sources.jar: com/amazonaws/services/inspector/model/transform/ListAssessmentTemplatesRequestMarshaller.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.inspector.model.transform;

import java.io.ByteArrayInputStream;
import java.util.Collections;
import java.util.Map;
import java.util.List;
import java.util.regex.Pattern;

import com.amazonaws.AmazonClientException;
import com.amazonaws.Request;
import com.amazonaws.DefaultRequest;
import com.amazonaws.http.HttpMethodName;
import com.amazonaws.services.inspector.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.BinaryUtils;
import com.amazonaws.util.StringUtils;
import com.amazonaws.util.IdempotentUtils;
import com.amazonaws.util.StringInputStream;
import com.amazonaws.protocol.json.*;

/**
 * ListAssessmentTemplatesRequest Marshaller
 */
public class ListAssessmentTemplatesRequestMarshaller
        implements
        Marshaller<Request<ListAssessmentTemplatesRequest>, ListAssessmentTemplatesRequest> {

    private final SdkJsonProtocolFactory protocolFactory;

    public ListAssessmentTemplatesRequestMarshaller(
            SdkJsonProtocolFactory protocolFactory) {
        this.protocolFactory = protocolFactory;
    }

    public Request<ListAssessmentTemplatesRequest> marshall(
            ListAssessmentTemplatesRequest listAssessmentTemplatesRequest) {

        if (listAssessmentTemplatesRequest == null) {
            throw new AmazonClientException(
                    "Invalid argument passed to marshall(...)");
        }

        Request<ListAssessmentTemplatesRequest> request = new DefaultRequest<ListAssessmentTemplatesRequest>(
                listAssessmentTemplatesRequest, "AmazonInspector");
        request.addHeader("X-Amz-Target",
                "InspectorService.ListAssessmentTemplates");

        request.setHttpMethod(HttpMethodName.POST);

        request.setResourcePath("");

        try {
            final StructuredJsonGenerator jsonGenerator = protocolFactory
                    .createGenerator();

            jsonGenerator.writeStartObject();

            java.util.List<String> assessmentTargetArnsList = listAssessmentTemplatesRequest
                    .getAssessmentTargetArns();
            if (assessmentTargetArnsList != null) {
                jsonGenerator.writeFieldName("assessmentTargetArns");
                jsonGenerator.writeStartArray();
                for (String assessmentTargetArnsListValue : assessmentTargetArnsList) {
                    if (assessmentTargetArnsListValue != null) {
                        jsonGenerator.writeValue(assessmentTargetArnsListValue);
                    }
                }
                jsonGenerator.writeEndArray();
            }
            if (listAssessmentTemplatesRequest.getFilter() != null) {
                jsonGenerator.writeFieldName("filter");
                AssessmentTemplateFilterJsonMarshaller.getInstance().marshall(
                        listAssessmentTemplatesRequest.getFilter(),
                        jsonGenerator);
            }
            if (listAssessmentTemplatesRequest.getNextToken() != null) {
                jsonGenerator.writeFieldName("nextToken").writeValue(
                        listAssessmentTemplatesRequest.getNextToken());
            }
            if (listAssessmentTemplatesRequest.getMaxResults() != null) {
                jsonGenerator.writeFieldName("maxResults").writeValue(
                        listAssessmentTemplatesRequest.getMaxResults());
            }

            jsonGenerator.writeEndObject();

            byte[] content = jsonGenerator.getBytes();
            request.setContent(new ByteArrayInputStream(content));
            request.addHeader("Content-Length",
                    Integer.toString(content.length));
            request.addHeader("Content-Type", protocolFactory.getContentType());
        } catch (Throwable t) {
            throw new AmazonClientException(
                    "Unable to marshall request to JSON: " + t.getMessage(), t);
        }

        return request;
    }

}
